import { AlphabetLowercase, AlphabetUppercase } from './alphabet';
export interface IFlagBase {
    name?: string;
    char?: AlphabetLowercase | AlphabetUppercase;
    description?: string;
    hidden?: boolean;
    required?: boolean;
}
export interface IBooleanFlag extends IFlagBase {
    type: 'boolean';
    allowNo: boolean;
    value: boolean;
}
export declare type ParseFn<T> = (input: string, options: {
    [k: string]: any;
}) => T;
export interface IOptionFlagBase<T> extends IFlagBase {
    type: 'option';
    parse: ParseFn<T>;
    multiple: boolean;
}
export interface ISingleOptionFlag<T> extends IOptionFlagBase<T> {
    multiple: false;
    default?: T;
    value: T;
}
export interface IMultiOptionFlag<T> extends IOptionFlagBase<T> {
    multiple: true;
    default?: undefined;
    value: T[];
}
export declare type IOptionFlag<T> = ISingleOptionFlag<T> | IMultiOptionFlag<T>;
export declare type FlagBuilder<T> = {
    (options: Partial<IMultiOptionFlag<T>>): IMultiOptionFlag<T>;
    (options?: Partial<ISingleOptionFlag<T>>): ISingleOptionFlag<T>;
};
export declare function option<T>(defaults: (Partial<IOptionFlag<T>>) & {
    parse: ParseFn<T>;
}): FlagBuilder<T>;
export declare type IFlag<T> = IBooleanFlag | IOptionFlag<T>;
export declare const flags: {
    boolean: (options?: Partial<IBooleanFlag>) => IBooleanFlag;
    integer: FlagBuilder<number>;
    option: <T>(defaults: (Partial<ISingleOptionFlag<T>> & {
        parse: ParseFn<T>;
    }) | (Partial<IMultiOptionFlag<T>> & {
        parse: ParseFn<T>;
    })) => FlagBuilder<T>;
    string: FlagBuilder<string>;
};
export declare const defaultFlags: {
    color: IBooleanFlag;
};
