import { IArg, Arg } from './args';
import { IBooleanFlag, IFlag } from './flags';
export interface InputFlags {
    [name: string]: IFlag<any>;
}
export declare type InputArgs = IArg<any>[];
export declare type parserInput<T extends InputFlags> = {
    argv: string[];
    flags: T;
    args: Arg<any>[];
    strict: boolean;
};
export declare type ParserInput<T extends InputFlags> = {
    argv?: string[];
    flags?: T;
    args?: InputArgs;
    strict?: boolean;
};
export declare type DefaultFlags = {
    color: IBooleanFlag;
};
export declare type outputFlags<T extends InputFlags> = {
    [P in keyof T]: T[P]['value'];
};
export declare type OutputFlags<T extends InputFlags> = outputFlags<T> & DefaultFlags;
export declare type OutputArgs = {
    [k: string]: string;
};
export declare type ParserOutput<T extends InputFlags> = {
    flags: OutputFlags<T>;
    args: OutputArgs;
    argv: string[];
    raw: ParsingToken[];
};
export declare type ArgToken = {
    type: 'arg';
    input: string;
};
export declare type FlagToken = {
    type: 'flag';
    flag: string;
    input: string;
};
export declare type ParsingToken = ArgToken | FlagToken;
export declare function parse<T extends InputFlags>(options: ParserInput<T>): ParserOutput<T>;
