"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const required_args_1 = require("./errors/required_args");
const required_flag_1 = require("./errors/required_flag");
const unexpected_args_1 = require("./errors/unexpected_args");
function validateArgs(expected, input) {
    const maxArgs = expected.args.length;
    if (expected.strict && input.length > maxArgs) {
        const extras = input.slice(maxArgs);
        throw new unexpected_args_1.UnexpectedArgsError(extras);
    }
    const requiredArgs = expected.args.filter(a => a.required || a.optional === false);
    const missingRequiredArgs = requiredArgs.slice(input.length);
    if (missingRequiredArgs.length) {
        throw new required_args_1.RequiredArgsError(missingRequiredArgs);
    }
}
function validateFlags(expected) {
    const requiredFlags = Object.keys(expected.flags)
        .map(k => [k, expected.flags[k]])
        .filter(([, flag]) => flag.required);
    for (const [, flag] of requiredFlags) {
        if (flag.value === undefined) {
            throw new required_flag_1.RequiredFlagError(flag);
        }
    }
}
function validate(expected, input) {
    const args = input.raw.filter(a => a.type === 'arg');
    validateArgs(expected, args);
    validateFlags(expected);
}
exports.validate = validate;
